@@ -18,19 +18,15 @@
 
 """Utilities for dijitso parameters."""
 
-from __future__ import unicode_literals
-
-from six import string_types
-from six.moves import configparser
-
 from glob import glob
 import os
 import sys
 import copy
 import numbers
+import configparser
 
 from dijitso.log import info, error, warning
-from dijitso.py23 import as_unicode
+from dijitso.str import as_unicode
 
 
 # Warning for fenics backwards compatibility:
@@ -190,10 +186,10 @@ def as_bool(value):
 def as_str_tuple(p):
     """Convert p to a tuple of strings, allowing a list or tuple of
 strings or a single string as input."""
-    if isinstance(p, string_types):
+    if isinstance(p, str):
         return (as_unicode(p),)
     elif isinstance(p, (tuple, list)):
-        if all(isinstance(item, string_types) for item in p):
+        if all(isinstance(item, str) for item in p):
             return tuple(as_unicode(item) for item in p)
     raise RuntimeError("Expecting a string or list of strings, not %s." % (p,))
 
@@ -254,7 +250,7 @@ def validate_params(params):
         for name, value in p[category].items():
             name = as_unicode(name)
             v0 = p0[category][name]
-            if isinstance(v0, string_types):
+            if isinstance(v0, str):
                 value = as_unicode(value)
                 # Expand paths including "~" to include
                 # full user home directory path
